#!/usr/bin/python3
# EASY-INSTALL-DEV-SCRIPT: 'ork.build==0.0.32','obt.ix.sysdeps.install.linuxcnc.py'
__requires__ = 'ork.build==0.0.32'
__import__('pkg_resources').require('ork.build==0.0.32')
__file__ = '/nvme4/aphidsystems/ork.build/bin_pub/obt.ix.sysdeps.install.linuxcnc.py'
with open(__file__) as f:
    exec(compile(f.read(), __file__, 'exec'))
